/*
 * For licensing terms, see the file COPYING
 * For contact information, see the file AUTHORS
 */
#ifndef _FN_H_
#define _FN_H_
#define FNRC ".fnrc"
#define FNRC_LEN 5

#define ENV_HTTP_PROXY "http_proxy"
#define ENV_HOME "HOME"

#define FOLDER_CHAR '/'

#define PROG_NAME 	"fn"
#ifndef VERSION
	#define VERSION 	"0.2.0"
#endif
#define BUILD_DATE  __DATE__	

#ifdef DEBUG
# define OPT_SHOW_ALLOC_STATS  	1<<0
#endif

#define OPT_DUMP_REPORT 		1<<1  /*-d*/
#define OPT_VERBOSE				1<<2  /*-v*/
#define OPT_QUIET				1<<3  /*-q*/
#define OPT_HELP				1<<4  /*-h*/
#define OPT_VERSION				1<<5  /*-version*/
#define OPT_SAVE_XML			1<<6  /*-r*/
#define OPT_NO_SORT				1<<7  /*--no--sort*/
#define OPT_SUPPRESS_ERRORS		1<<8  /*--Q*/
#define OPT_SAVE_ALL 			1<<9  /*-s*/
#define OPT_NO_PROXY			1<<10 /*--no-proxy*/

#include <stdarg.h>
#include "item.h"
// #define has_option(t,x)	((t&x)==x)
typedef struct _HTTP_REQUEST
{
	char * version;
	char * connection;
	char * agent;
	char * host;
	int port;
}HTTP_REQUEST;

typedef struct _CHANNEL_LIST
{
	char *url;
	char *description;
	char *type;
	struct _CHANNEL_LIST *next;
}CHANNEL_LIST;

typedef struct _MAIL_INFO
{
	char * mail_to;
	char * mail_from;
	char * mail_subject;
	char * mail_headers;  /* Additional headers */
	char * mail_template;
	char * mail_report;
	char * mail_program; /*Program to send mail */
}MAIL_INFO;

/*
 * All pointer members should point to
 * heap-allocated memory and should be
 * explicitly freed
 */
typedef struct
{
	int options;
	int proxy_port;
	int timeout;
	char * proxy;
	char * channel_file;
	char * template_file;
	char * config_file;
	char * address;
	char * score_file;
	char * report_file;
	char * raw_file;
	char * xml_dir;
	CHANNEL_LIST *channels;
	SCORE_LIST *score_list;
	HTTP_REQUEST *http_request;
	MAIL_INFO * mail_info;
}FN_OPTIONS;

#define has_option(x) (((fn->options)&(x))==(x))

void verbose(const char *text,...);
void print(const char *text,...);
void error(const char *text,...);
void add_channel(char *_url,char *_description,char *_type);

#endif //_FN_H_
